Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CalculateExpiryTime ¶
CalculateExpiryTime calculates the expiry time based on minutes
func GenerateOTP ¶
GenerateOTP creates a random OTP of the specified length
func HashPassword ¶
HashPassword creates a bcrypt hash from the provided password
func VerifyPassword ¶
VerifyPassword compares a bcrypt hashed password with its possible plaintext equivalent
Types ¶
Click to show internal directories.
Click to hide internal directories.